Crate ros2kit

Crate ros2kit 

ROS 2 toolkit library for ament environment discovery, process management, launch file support, and log file discovery.

Optional features: workspace for workspace scanning and overlay management, colcon for build integration.

Re-exports

pub use ament::Env;
pub use ament::Executable;
pub use ament::InterfaceDef;
pub use ament::InterfaceKind;
pub use ament::LaunchFile;
pub use ament::LaunchFormat;
pub use ament::Package;
pub use launch::LaunchArg;
pub use process::LaunchType;
pub use process::Launcher;

Modules

ament
Ament environment discovery: installed packages, executables, launch files, interfaces.
launch
Launch file argument parsing via Python helper.
log
ROS 2 log file discovery and tailing.
process
Process launching, lifecycle management, and output streaming.