Launch file argument parsing via Python helper.
Structs
- Launch
Arg - A declared argument from a ROS 2 launch file.
Functions
- helper_
path - Writes the embedded Python helper script to the cache directory and returns its path.
- parse_
launch_ args - Invokes the helper script to extract declared arguments from a ROS 2 launch file.